//! Data models for sprinklers sections
//!
//! A section represents a group of sprinkler heads actuated by a single
//! valve. Physically controllable (or virtual) valves are handled by implementations of
//! [SectionInterface](../../section_interface/trait.SectionInterface.html), but the model
//! describes a logical section and how it maps to a physical one.

use crate::section_interface::SecId;
use serde::{Deserialize, Serialize};
use std::sync::Arc;

/// Identifying integer type for a Section
pub type SectionId = u32;

/// A single logical section
#[derive(Debug, Clone, Serialize, Deserialize)]
#[serde(rename_all = "camelCase")]
pub struct Section {
    pub id: SectionId,
    pub name: String,
    /// ID number of the corresponding physical section
    pub interface_id: SecId,
}

pub type SectionRef = Arc<Section>;

pub type Sections = im::OrdMap<SectionId, SectionRef>;
